![PyPI - Python Version](https://img.shields.io/pypi/pyversions/RPi.rotary-menu)
![PyPI - Version](https://img.shields.io/pypi/v/RPi.rotary-menu)
![PyPI - License](https://img.shields.io/pypi/l/RPi.rotary-menu)
![GitHub issues](https://img.shields.io/github/issues/FyrfyX8/RotaryMenu)
![GitHub commit activity (branch)](https://img.shields.io/github/commit-activity/m/FyrfyX8/RotaryMenu)

# RotaryMenu
A Python library for Raspberry Pi to display and control a rotary menu on a CharLCD.

# Installation

To install this library use:

`pip install RPi.rotary-menu`

you also need to install RPi.GPIO on your Raspberry Pi

# Documentation

[Click here!](https://github.com/FyrfyX8/RotaryMenu/blob/main/docs/RotaryMenu-docs.md)


